
```bash

python3 -m unittest src/exfill/tests/extractor_tests.py 

$ python3 -m unittest src/exfill/tests/parser_factory_tests.py

$ python3 -m unittest src/exfill/tests/parser_linkedin_export_props_tests.py
```